# Tutorial

What makes plasmas particularly difficult to analyze is the fact that the densities fall in an intermediate range. Fluids like water are so dense that the motions of individual molecules do not have to be considered. Collisions dominate, and the simple equations of ordinary fluid dynamics suffice. At the other extreme in very low-density devices, only single-particle trajectories need to be considered; collective effects are often unimportant. Plasma behaves sometimes like fluids, and sometimes like a collection of individual particles. The first step in learning how to deal with this schizophrenic personality is to understand how single particles behave in electric and magnetic fields.

Here we assume that the EM fields are prescribed and not affected by the charged particles. The materials here closely follows F.F.Chen's [Introduction to Plasma Physics and Controlled Fusion](https://link.springer.com/book/10.1007/978-3-319-22309-4).

In all examples we assume the following packages are loaded:

```@example tutorial
using JSServe: Page # hide
Page(exportable=true, offline=true) # hide
```

```@example tutorial
using TestParticle
using TestParticle: get_gc
using TestParticleMakie
using OrdinaryDiffEq
using StaticArrays
using LinearAlgebra
import WGLMakie as WM
```

## Uniform E and B Fields

### E=0

In this case, a charged particle has a simple cyclotron gyration. The equation of motion is

```math
m\frac{d\mathbf{V}}{dt} = q\mathbf{V}\times\mathbf{B}
```

Taking ``\widehat{z}`` to be the direction of ``\mathbf{B}`` (``\mathbf{B} = B\widehat{z}``), we have

```math
\begin{aligned}
m\dot{v}_x = qB v_y,\, m\dot{v}_y = -qB v_x,\, m\dot{v}_z = 0, \\
\ddot{v}_x = \frac{qB}{m}\dot{v}_y = -\big( \frac{qB}{m}\big)^2 v_x \\
\ddot{v}_y = \frac{qB}{m}\dot{v}_x = -\big( \frac{qB}{m}\big)^2 v_y
\end{aligned}
```

This describes a simple harmonic oscillator at the *cyclotron frequency*, which we define to be

```math
\omega_c \equiv \frac{| q | B}{m}
```

By the convention we have chosen, ``\omega_c`` is always nonnegative. The solution of velocity is then

```math
v_{x,y} = v_\perp \exp(\pm i \omega_c t + i\delta_{x,y})
```

The ``\pm`` denote the sign of q. We may choose the phase ``\delta`` so that

```math
v_x = v_\perp e^{i\omega_c t} = \dot{x}
```

where ``v_\perp`` is a positive constant denoting the speed in the plane perpendicular to ``\mathbf{B}``. Then

```math
v_y  = \frac{m}{qB} \dot{v}_x = \pm \frac{1}{\omega_c}\dot{v}_x = \pm i v_\perp e^{i\omega_c t} = \dot{y}
```

Integrating once again, we have

```math
\begin{aligned}
x - x_0 &= -i\frac{v_\perp}{\omega_c}e^{i\omega_c t} \\
y - y_0 &= \pm i\frac{v_\perp}{\omega_c}e^{i\omega_c t}
\end{aligned}
```

We define the *Larmor radius* to be

```math
r_L \equiv \frac{v_\perp}{\omega_c} = \frac{mv_\perp}{|q| B}
```

Taking the real part of the positions, we have

```math
\begin{aligned}
x - x_0 &= r_L\sin\omega_c t \\
y - y_0 &= \pm r_L \cos\omega_c t  
\end{aligned} 
```

This describes a circular orbit about a *guiding center* (``x_0, y_0``) which is fixed. The direction of the gyration is always such that the magnetic field generated by the charged particle is opposite to the externally imposed field. Plasma particles, therefore, tend to *reduce* the magnetic field, and plasmas are *diamagnetic*. In addition to this motion, there is an arbitrary velocity ``v_z`` along ``\mathbf{B}`` which is not affected by ``\mathbf{B}``. The trajectory of a charged particle in space is, in general, a helix.

```@example tutorial
function uniform_B(x)
    return SA[0.0, 0.0, 1e-8]
end

function uniform_E(x)
    return SA[0.0, 0.0, 0.0]
end

x0 = [1.0, 0, 0]
v0 = [0.0, 1.0, 0.1]
stateinit = [x0..., v0...]
tspan = (0, 18)

param = prepare(uniform_E, uniform_B, species=Proton)
prob = ODEProblem(trace!, stateinit, tspan, param)
sol = solve(prob, Tsit5(); save_idxs=[1,2,3,4,5,6])

WM.plot(sol)
```

### Finite E

If now we allow an electric field to be present, the motion will be found to be the sum of two motions: the usual circular Larmor gyration plus a drift of the guiding center. We may choose ``\mathbf{E}`` to lie in the x-z plane so that ``E_y = 0``. As before, the z component of velocity is unrelated to the transverse components and can be treated separately. The equations of motion is now

```math
m\frac{d\mathbf{V}}{dt} = q( \mathbf{E} + \mathbf{V}\times\mathbf{B} )
```

whose z component is

```math
\frac{dv_z}{dt} = \frac{q}{m}E_z
```

or

```math
v_z = \frac{qE_z}{m}t + v_{z0}
```

This is a straightforward acceleration along ``\mathbf{B}``. The transverse components are

```math
\begin{aligned}
\frac{dv_x}{dt} &= \frac{q}{m}E_x \pm \omega_c v_y \\
\frac{dv_y}{dt} &= 0 \mp \omega_c v_x
\end{aligned}
```

Differentiating, we have (for constant ``\mathbf{E}``)

```math
\begin{aligned}
\ddot{v}_x &= -\omega_c^2 v_x \\
\ddot{v}_y &= \mp \omega_c \Big( \frac{q}{m}E_x \pm \omega_c v_y \Big) = -\omega_c^2 \Big( v_y + \frac{E_x}{B} \Big)
\end{aligned}
```

We can write this as

```math
\frac{d^2}{dt^2}\Big( v_y + \frac{E_x}{B} \Big) = -\omega_c^2\Big( v_y + \frac{E_x}{B} \Big)
```

so that it reduces to the previous case if we replace ``v_y`` by ``v_y + (E_x/B)``. The velocity solution is then replaced by

```math
\begin{aligned}
v_x &= v_\perp e^{i\omega_c t} \\
v_y &= \pm v_\perp e^{i\omega_c t} - \frac{E_x}{B}
\end{aligned}
```

The Larmor motion is the same as before, but there is superimposed a drift ``\mathbf{v}_{gc}`` of the guiding center in the -y direction (for ``E_x > 0``).

To obtain a general formula for ``\mathbf{v}_{gc}``, we can solve the momentum equation in vector form. We may omit the ``m d\mathbf{v}/dt`` term, since this term gives only the circular motion at ``\omega_c``, which we already know about. Then the momentum equation becomes

```math
\mathbf{E} + \mathbf{v}\times\mathbf{B} = 0
```

Taking the cross product with ``\mathbf{B}``, we have

```math
\mathbf{E}\times\mathbf{B} = \mathbf{B}\times(\mathbf{v}\times\mathbf{B}) = \mathbf{v}B^2 - \mathbf{B}(\mathbf{v}\cdot\mathbf{B})
```

The transverse components of this equation are

```math
\mathbf{v}_{gc} = \mathbf{E}\times\mathbf{B}/B^2 \equiv \mathbf{v}_E
```

We define this to be ``\mathbf{v}_E``, the electric field drift of the guiding center. In magnitude, this drift is

```math
v_E = \frac{E(\text{V/m})}{B(\text{tesla})}\frac{\text{m}}{\text{sec}}
```

It is important to note that ``\mathbf{v}_E`` is independent of q, m, and ``v_\perp``. The reason is obvious from the following physical picture. In the first half-cycle of the ion’s orbit, it gains energy from the electric field and increases in ``v_\perp`` and, hence, in ``r_L``. In the second half-cycle, it loses energy and decreases in ``r_L``. This difference in ``r_L`` on the left and right sides of the orbit causes the drift ``v_E``. A negative electron gyrates in the opposite direction but also gains energy in the opposite direction; it ends up drifting in the same direction as an ion. For particles of the same velocity but different mass, the lighter one will have smaller ``r_L`` and hence drift less per cycle. However, its gyration frequency is also larger, and the two effects exactly cancel. Two particles of the same mass but different energy would have the same ``\omega_c``. The slower one will have smaller ``r_L`` and hence gain less energy from ``\mathbf{E}`` in a half-cycle. However, for less energetic particles the fractional change in ``r_L`` for a given change in energy is larger, and these two effects cancel.

The three-dimensional orbit in space is therefore a slanted helix with changing pitch.

```@example tutorial
function uniform_B(x)
    return SA[0, 0, 1e-8]
end

function uniform_E(x)
    return SA[1e-9, 0, 0]
end

# trace the orbit of the guiding center
function trace_gc!(dx, x, p, t)
    _, _, E, B, sol = p
    xu = sol(t)
    Bv = B(x)
    b = normalize(Bv)
    v_par = (xu[4:6]⋅b).*b
    B2 = sum(Bv.^2)
    dx[1:3] = (E(x)×Bv)/B2 + v_par
end

x0 = [1.0, 0, 0]
v0 = [0.0, 1.0, 0.1]
stateinit = [x0..., v0...]
tspan = (0, 20)
# E×B drift
param = prepare(uniform_E, uniform_B, species=Proton)
prob = ODEProblem(trace!, stateinit, tspan, param)
sol = solve(prob, Tsit5(); save_idxs=[1,2,3,4,5,6])

gc = get_gc(param)
gc_x0 = [gc_i(stateinit) for gc_i in gc]
prob_gc = ODEProblem(trace_gc!, gc_x0, tspan, (param..., sol))
sol_gc = solve(prob_gc, Tsit5(); save_idxs=[1,2,3])

gc_analytic = Tuple(xu -> getindex(sol_gc(xu[7]), i) for i = 1:3)
# numeric result and analytic result
orbit(sol, vars=[(1, 2, 3), gc, gc_analytic])
```

### Gravitational Field

The foregoing result can be applied to other forces by replacing ``q\mathbf{E}`` in the equation of motion by a general force ``\mathbf{F}``. The guiding center drift caused by ``\mathbf{F}`` is then

```math
\mathbf{v}_f = \frac{1}{q}\frac{\mathbf{F}\times\mathbf{B}}{B^2}
```

In particular, if ``\mathbf{F}`` is the force of gravity ``m\mathbf{g}``, there is a drift

```math
\mathbf{v}_g = \frac{m}{q}\frac{\mathbf{g}\times\mathbf{B}}{B^2}
```

This is similar to the drift ``\mathbf{v}_E`` in that it is perpendicular to both the force and ``\mathbf{B}``, but it differs in one important respect. The drift ``\mathbf{v}_g`` changes sign with the particle’s charge. Under a gravitational force, ions and electrons drift in opposite directions, so there is a net current density in the plasma given by

```math
\mathbf{j} = n(M+m)\frac{\mathbf{g}\times\mathbf{B}}{B^2}
```

The physical reason for this drift is again the change in Larmor radius as the particle gains and loses energy in the gravitational field. Now the electrons gyrate in the opposite sense to the ions, but the force on them is in the same direction, so the drift is in the opposite direction. The magnitude of ``\mathbf{v}_g`` is usually negligible, but when the lines of force (i.e. magnetic field lines) are curved, there is an effective gravitational force due to centrifugal force. This force, which is not negligible, is independent of mass; this is why we did not stress the m dependence of the drift here. Centrifugal force is the basis of a plasma instability called the “gravitational” instability, which has nothing to do with real gravity.

```@example tutorial
function B(x)
    return SA[0.0, 1e-8, 0.0]
end

function E(x)
    return SA[0.0, 0.0, 0.0]
end
# gravity
function F(x)
    return SA[0.0, 0.0, -TestParticle.mᵢ*9.8]
end
# initial static particle
x0 = [1.0, 0, 0]
v0 = [0.0, 0.0, 0.0]
stateinit = [x0..., v0...]
tspan = (0, 1.0)

param = prepare(E, B, F, species=Proton)
prob = ODEProblem(trace!, stateinit, tspan, param)
sol = solve(prob, Tsit5(); save_idxs=[1,2,3])
# drift in x-direction + free fall in z-direction
WM.plot(sol)
```

## Nonuniform B Field

Now that the concept of a guiding center drift is firmly established, we can discuss the motion of particles in inhomogeneous fields — ``\mathbf{E}`` and ``\mathbf{B}`` fields which vary in space or time. For uniform fields we were able to obtain exact expressions for the guiding center drifts. As soon as we introduce inhomogeneity, the problem becomes too complicated to solve exactly. To get an approximate answer, it is customary to expand in the small ratio ``r_L/L``, where L is the scale length of the inhomogeneity. This type of theory, called *orbit theory*, can become extremely involved. We shall examine only the simplest cases, where only one inhomogeneity occurs at a time.

### ∇B ⊥ B: Grad-B Drift

Here the magnetic field lines are straight, but their density increases, say, in the y direction. We can anticipate the result by using our simple physical picture. The gradient in |B| causes the Larmor radius to be larger at the bottom of the orbit than at the top, and this should lead to a drift, in opposite directions for ions and electrons, perpendicular to both B and ``\nabla B``. The drift velocity should obviously be proportional to ``r_L/L`` and to ``v_\perp``.

Consider the Lorentz force ``\mathbf{F} = q\mathbf{v}\times\mathbf{B}``, averaged over a gyration. Clearly, ``\bar{F}_x = 0``, since the particle spends as much time moving up as down. We wish to calculate ``\bar{F}_y``, in an approximate fashion, by using the *undisturbed orbit* of the particle to find the average. The undisturbed orbit is given by the solution in the first section for a uniform ``\mathbf{B}`` field. Taking the real part of the solution for ``v_x`` and ``y``, we have

```math
F_y = -q v_x B_z(y) = -q v_\perp(\cos \omega_c t) \Big[ B_0 \pm r_L(\cos\omega_c t )\frac{\partial B}{\partial y} \Big]
```

where we have made a Taylor expansion of ``\mathbf{B}`` field about the point ``x_0=0, y_0=0``

```math
\begin{aligned}
\mathbf{B} &= \mathbf{B}_0 + (\mathbf{r}\cdot\nabla)\mathbf{B} + ... \\
Bz &= B_0 + y(\partial B_z/\partial y) + ...
\end{aligned}
```

This expansion of course requires ``r_L / L \ll 1``, where L is the length scale of ``\partial Bz/\partial y``. The first term above averages to zero in a gyration, and the average of ``\cos^2 \omega_c t`` is ``1/2``, so that

```math
\bar{F}_y = \mp q v_\perp r_L \frac{1}{2}\frac{\partial B}{\partial y}
```

The guiding center drift velocity is then

```math
\mathbf{v}_{gc} = \frac{1}{q}\frac{\mathbf{F}\times\mathbf{B}}{B^2} = \frac{1}{q}\frac{\bar{F}_y}{|B|}\widehat{x} = \mp \frac{v_\perp r_L}{B}\frac{1}{2} \frac{\partial B}{\partial y} \widehat{x}
```

where we have used the formula shown previously. Since the choice of the y axis was arbitrary, this can be generalized to

```math
\mathbf{v}_{\nabla B} = \pm v_\perp r_L \frac{\mathbf{B}\times \nabla B}{B^2}
```

This has all the dependences we expected from the physical picture; only the factor ``\frac{1}{2}`` (arising from the averaging) was not predicted. Note that the ``\pm`` stands for the sign of the charge, and lightface ``B`` stands for ``|B|``. The quantity ``\mathbf{v}_{\nabla B}`` is called the *grad-B drift*; it is in opposite directions for ions and electrons and causes a current transverse to ``\mathbf{B}``. An exact calculation of ``\mathbf{v}_{\nabla B}`` would require using the exact orbit, including the drift, in the averaging process.

```@example tutorial
using ForwardDiff: gradient

function grad_B(x)
    return SA[0, 0, 1e-8+1e-9 *x[2]]
end

function uniform_E(x)
    return SA[1e-9, 0, 0]
end

abs_B(x) = norm(grad_B(x))

# trace the orbit of the guiding center
function trace_gc!(dx, x, p, t)
    q, m, E, B, sol = p
    xu = sol(t)
    gradient_B = gradient(abs_B, x)
    Bv = B(x)
    b = normalize(Bv)
    v_par = (xu[4:6]⋅b).*b
    v_perp = xu[4:6] - v_par
    dx[1:3] = m*norm(v_perp)^2*(Bv×gradient_B)/(2*q*norm(Bv)^3) + (E(x)×Bv)/norm(Bv)^2+v_par
end

x0 = [1.0, 0, 0]
v0 = [0.0, 1.0, 0.1]
stateinit = [x0..., v0...]
tspan = (0, 20)
param = prepare(uniform_E, grad_B, species=Proton)
prob = ODEProblem(trace!, stateinit, tspan, param)
sol = solve(prob, Tsit5(); save_idxs=[1,2,3,4,5,6])

gc = get_gc(param)
gc_x0 = [gc_i(stateinit) for gc_i in gc]
prob_gc = ODEProblem(trace_gc!, gc_x0, tspan, (param..., sol))
sol_gc = solve(prob_gc, Tsit5(); save_idxs=[1,2,3])

gc_analytic = Tuple(xu -> getindex(sol_gc(xu[7]), i) for i = 1:3)
# numeric result and analytic result
# The orbit of guiding center includes some high order terms, which is different from the
# formula of magnetic field gradient drift of some textbooks that just preserves the first
# order term.
orbit(sol, vars=[(1, 2, 3), gc, gc_analytic])
```

### Curved B: Curvature Drift

Here we assume the magnetic field lines to be curved with a constant radius of curvature ``R_c``, and we take ``|B|`` to be constant. Such a field does not obey Maxwell’s equations in a vacuum, so in practice the grad-B drift will always be added to the
effect derived here. A guiding center drift arises from the centrifugal force felt by the particles as they move along the field lines in their thermal motion. If ``v_\parallel^2`` denotes the average square of the component of random velocity along ``\mathbf{B}``, the average centrifugal force is

```math
\mathbf{F}_{cf} = \frac{mv_\parallel^2}{R_c}\widehat{r} = mv_\parallel^2\frac{\mathbf{R}_c}{R_c^2}
```

According to the guiding center drift formula, this gives rise to a drift

```math
\mathbf{v}_{R} = \frac{1}{q}\frac{\mathbf{F}_{cf}\times\mathbf{B}}{B^2} = \frac{mv_\parallel^2}{qB^2}\frac{\mathbf{R}_c \times\mathbf{B}}{R_c^2}
```

The drift ``\mathbf{v}_R`` is called the *curvature drift*.

We must now compute the grad-B drift which accompanies this when the decrease of ``|B|`` with radius is taken into account. In a vacuum, we have ``\nabla\times\mathbf{B} = 0``. In the cylindrical coordinates, ``\nabla\times\mathbf{B}`` only has a ``z`` component, since ``\mathbf{B}`` has only a ``\theta`` component and ``\nabla B`` only an ``r`` component. We then have

```math
(\nabla\times\mathbf{B})_z = \frac{1}{r}\frac{\partial}{\partial r}(rB_\theta) = 0,\, B\propto \frac{1}{r}
```

Thus

```math
|B| \propto \frac{1}{R_c},\, \frac{\nabla B}{B} = - \frac{\mathbf{R}_c}{R_c^2}
```

Using the expression of the grad-B drift, we have

```math
\mathbf{v}_{\nabla B} = \mp \frac{1}{2}\frac{v_\perp r_L}{B^2}\frac{B}\times |B| \frac{\mathbf{R}_c}{R_c^2} = \pm \frac{1}{2}\frac{v_\perp^2}{\omega_c}\frac{\mathbf{R}_c\times\mathbf{B}}{R_c^2 B} = \frac{1}{2}\frac{m}{q}v_\perp^2\frac{\mathbf{R}_c\times\mathbf{B}}{R_c^2 B^2}
```

Adding this to ``\mathbf{v}_R`` , we have the total drift in a curved vacuum field:

```math
\mathbf{v}_R + \mathbf{v}_{\nabla B} = \frac{m}{q}\frac{\mathbf{R}_c\times\mathbf{B}}{R_c^2 B^2}\Big( v_\parallel^2 + \frac{1}{2}v_\perp^2 \Big)
```

It is unfortunate that these drifts add. This means that if one bends a magnetic field into a torus for the purpose of confining a thermonuclear plasma, the particles will drift out of the torus no matter how one juggles the temperatures and magnetic fields.

For a Maxwellian distribution, ``\bar{v_\parallel^2}`` and ``\frac{1}{2}\bar{v_\perp^2}`` are each equal to ``k_B T/m``, since ``v_\perp`` involves two degrees of freedom. Then the average curved-field drift can be written as

```math
\bar{\mathbf{v}}_{R+\nabla B} = \pm \frac{v_{th}^2}{R_c\omega_c}\widehat{y} = \pm\frac{\bar{r}_L}{R_c}v_{th}\widehat{y}
```

where ``\widehat{y}`` here is the direction of ``\widehat{R}_c\times\mathbf{B}``. This shows that ``\bar{\mathbf{v}}_{R+\nabla B}`` depends on the charge of the species but not on its mass.

```@example tutorial
using ForwardDiff: gradient, jacobian

function curved_B(x)
    # satisify ∇⋅B=0
    # B_θ = 1/r => ∂B_θ/∂θ = 0
    θ = atan(x[3]/(x[1]+3))
    r = hypot(x[1]+3, x[3])
    return SA[-1e-7*sin(θ)/r, 0, 1e-7*cos(θ)/r]
end

function zero_E(x)
    return SA[0, 0, 0]
end

abs_B(x) = norm(curved_B(x))  # |B|

# trace the orbit of the guiding center
function trace_gc!(dx, x, p, t)
    q, m, E, B, sol = p
    xu = sol(t)
    gradient_B = gradient(abs_B, x)  # ∇|B|
    Bv = B(x)
    b = normalize(Bv)
    v_par = (xu[4:6]⋅b).*b  # (v⋅b)b
    v_perp = xu[4:6] - v_par
    Ω = q*norm(Bv)/m
    κ = jacobian(B, x)*Bv  # B⋅∇B
    # v⟂^2*(B×∇|B|)/(2*Ω*B^2) + v∥^2*(B×(B⋅∇B))/(Ω*B^3) + (E×B)/B^2 + v∥
    dx[1:3] = norm(v_perp)^2*(Bv×gradient_B)/(2*Ω*norm(Bv)^2) + 
                norm(v_par)^2*(Bv×κ)/Ω/norm(Bv)^3 + (E(x)×Bv)/norm(Bv)^2 + v_par
end

x0 = [1.0, 0, 0]
v0 = [0.0, 1.0, 0.1]
stateinit = [x0..., v0...]
tspan = (0, 40)
# E×B drift
param = prepare(zero_E, curved_B, species=Proton)
prob = ODEProblem(trace!, stateinit, tspan, param)
sol = solve(prob, Tsit5(); save_idxs=[1,2,3,4,5,6])

gc = get_gc(param)
gc_x0 = [gc_i(stateinit) for gc_i in gc]
prob_gc = ODEProblem(trace_gc!, gc_x0, tspan, (param..., sol))
sol_gc = solve(prob_gc, Tsit5(); save_idxs=[1,2,3])

gc_analytic = Tuple(xu -> getindex(sol_gc(xu[7]), i) for i = 1:3)
# numeric result and analytic result
# similar to the magnetic field gradient drift
# analytic calculation should include both of the gradient drift and the curvature drift
orbit(sol, vars=[(1, 2, 3), gc, gc_analytic])
```

### ∇B ∥ B: Magnetic Mirrors

Now we consider a magnetic field which is pointed primarily in the z direction and whose magnitude varies in the z direction. Let the field be axisymmetric, with ``B_\theta = 0`` and ``\partial/\partial\theta = 0``. Since the magnetic field lines converge and diverge, there is necessarily a component ``B_r``. We wish to show that this gives rise to a force which can trap a particle in a magnetic field.

We can obtain ``B_r`` from ``\nabla\cdot\mathbf{B} = 0``:

```math
\frac{1}{r}\frac{\partial}{\partial r}(rB_r) + \frac{\partial B_z}{\partial z} = 0
```

If ``\partial \mathbf{B}_z/\partial z`` is given at ``r=0`` and does not vary much with r, we have approximately

```math
\begin{aligned}
rB_r &= -\int_0^r r\frac{\partial B_z}{\partial z}dr \simeq -\frac{1}{2}r^2 \Big[ \frac{\partial \mathbf{B}_z}{\partial z} \Big]_{r=0} \\
B_r &= -\frac{1}{2}r \Big[ \frac{\partial \mathbf{B}_z}{\partial z} \Big]_{r=0}
\end{aligned}
```

The variation of ``|B|`` with r causes a grad-B drift of guiding centers about the axis of symmetry, but there is no radial grad-B drift, because ``\partial B/\partial \theta = 0``. The components of the Lorentz force are

```math
\begin{aligned}
F_r &= q(\underbrace{v_\theta B_z}_{\textcircled{\small{1}}} - v_z \cancel{B_\theta}) \\
F_\theta &= q(\underbrace{-v_r B_z}_{\textcircled{\small{2}}} + \underbrace{v_z B_r}_{\textcircled{\small{3}}}) \\
F_z &= q(v_r \cancel{B}_\theta - \underbrace{v_\theta B_r}_{\textcircled{\small{4}}})
\end{aligned}
```

Two terms vanish if ``B_\theta = 0``, and terms 1 and 2 give rise to the usual Larmor gyration. Term 3 vanishes on the axis; when it does not vanish, this azimuthal force causes a drift in the radial direction. This drift merely makes the guiding centers follow the magnetic field lines. Term 4 is the one we are interested in. Using the expression of ``B_r``, we have

```math
F_z = \frac{1}{2}q v_\theta r_L \frac{\partial B_z}{\partial z}
```

We must now average over one gyration. For simplicity, consider a particle whose guiding center lies on the axis. Then ``v_\theta`` is a constant during a gyration; depending on the sign of q, ``v_\theta`` is ``\mp v_\perp``. Since ``r = r_L`` , the average force is

```math
\bar{F}_z = \mp \frac{1}{2}q v_\perp r_L \frac{\partial B_z}{\partial z} = \mp \frac{1}{2}q\frac{v_\perp^2}{\omega_c} \frac{\partial B_z}{\partial z} = -\frac{1}{2}\frac{mv_\perp^2}{B} \frac{\partial B_z}{\partial z}
```

We define the *magnetic moment* of the gyrating particle to be

```math
\mu \equiv \frac{1}{2}mv_\perp^2 / B
```

so that

```math
\bar{F}_z = -\mu \frac{\partial B_z}{\partial z}
```

This is a specific example of the force on a diamagnetic particle, which in general can be written

```math
\mathbf{F}_\parallel = -\mu\frac{\partial B}{\partial \mathbf{s}} = -\mu\nabla_\parallel B
```

where ``d\mathbf{s}`` is a line element along ``\mathbf{B}``. Note that the definition of magnetic moment here is the same as the
usual definition for the magnetic moment of a current loop with area A and current I: ``\mu = IA``. In the case of a singly charged ion, I is generated by a charge e coming around ``\omega_c / 2\pi`` times a second: ``I = e\omega_c/2\pi``. The area A is ``\pi r_L^2 = \pi r_L^2/\omega_c^2``. Thus

```math
\mu = \frac{e\omega_c}{2\pi}\frac{\pi r_L^2}{\omega_c^2} = \frac{1}{2}\frac{v_\perp^2 e}{\omega_c} = \frac{1}{2}\frac{mv_\perp^2}{B}
```

As the particle moves into regions of stronger or weaker B, its Larmor radius changes, but *μ remains invariant*. To prove this, consider the component of the equation of motion along ``\mathbf{B}``:

```math
m\frac{dv_\parallel}{dt} = -\mu \frac{\partial B}{\partial s}
```

Multiplying by ``v_\parallel`` on the left and its equivalent ``ds/dt`` on the right, we have

```math
mv_\parallel \frac{dv_\parallel}{dt} = \frac{d}{dt}\Big( \frac{1}{2}mv_\parallel^2 \Big) = -\mu\frac{\partial B}{\partial s}\frac{ds}{dt} = -\mu\frac{dB}{dt}
```

Here dB/dt is the variation of B as seen by the particle; B itself is constant. The particle’s energy must be conserved, so we have

```math
\frac{d}{dt}\Big( \frac{1}{2}mv_\parallel^2 + \frac{1}{2}mv_\perp^2 \Big) = \frac{d}{dt}\Big( \frac{1}{2}mv_\parallel^2 + \mu B \Big) = 0
```

With the previous equation this becomes

```math
-\mu\frac{dB}{dt} + \frac{d}{dt}(\mu B) = 0
```

so that

```math
\frac{d\mu}{dt} = 0
```

The invariance of ``\mu`` is the basis for one of the primary schemes for plasma confinement: the *magnetic mirror*. As a particle moves from a weak-field region to a strong-field region in the course of its thermal motion, it sees an increasing B, and therefore its ``v_\perp`` must increase in order to keep μ constant. Since its total energy must remain constant, ``v_\parallel`` must necessarily decrease. If B is high enough in the “throat” of the mirror, ``v_\parallel`` eventually becomes zero; and the particle is “reflected” back to the weak-field region. It is, of course, the force ``\mathbf{F}_\parallel`` which causes the reflection. The nonuniform field of a simple pair of coil form two magnetic mirrors between which a plasma can be trapped. This effect works on both ions and electrons.

The trapping is not perfect, however. For instance, a particle with ``v_\perp = 0`` will have no magnetic moment and will not feel any force along ``\mathbf{B}``. A particle with small ``v_\perp / v_\parallel`` at the midplane (``B = B_0``) will also escape if the maximum field ``B_m`` is not large enough. For given ``B_0`` and ``B_m``, which particles will escape? A particle with ``v_\perp = v_{\perp 0}`` and ``v_\parallel = v_{\parallel 0}`` at the midplane will have ``v_\perp = v_\perp^\prime`` and ``v_\parallel = 0`` at its turning point. Let the field be ``B^\prime`` there. Then the invariants of ``\mu`` yields 

```math
\frac{1}{2}\frac{mv_{\perp 0}^2}{B_0} = \frac{1}{2}\frac{m{v_{\perp 0}^{\prime}}^2}{B^\prime}
```

Conservation of energy requires

```math
{v_{\perp 0}^{\prime}}^2 = v_{\perp 0}^2 + v_{\parallel 0}^2 \equiv v_0^2
```

Combining the above two equations, we find

```math
\frac{B_0}{B^\prime} = \frac{v_{\perp 0}^2}{{v_{\perp}^{\prime}}^2} \equiv \sin^2 \theta
```

where ``\theta`` is the pitch angle of the orbit in the weak-field region. Particles with smaller θ will mirror in regions of higher B. If θ is too small, ``B^\prime`` exceeds ``B_m``; and the particles does not mirror at all. Replacing ``B^\prime`` by ``B_m``, we see that the smallest ``\theta`` of a confined particle is given by

```math
\sin^2 \theta_m = \frac{B_0}{B_m} \equiv \frac{1}{R_m}
```

where ``R_m`` is the *mirror ratio*. It defines the boundary of a region in velocity space in the shape of a cone, called a *loss cone*. Particles lying within the loss cone are not confined. Consequently, a mirror-confined plasma is never isotropic. Note that the loss cone is independent of q or m. Without collisions, both ions and electrons are equally well confined. When collisions occur, particles are lost when they change their pitch angle in a collision and are scattered into the loss cone. Generally, electrons are lost more easily because they have a higher collision frequency.

The magnetic mirror was first proposed by Enrico Fermi as a mechanism for the acceleration of cosmic rays. Protons bouncing between magnetic mirrors approaching each other at high velocity could gain energy at each bounce. How such mirrors could arise is another story. A further example of the mirror effect is the confinement of particles in the Van Allen belts. The magnetic field of the earth, being strong at the poles and weak at the equator, forms a natural mirror with rather large ``R_m``.

## Nonuniform E Field

Now we let the magnetic field be uniform and the electric field be nonuniform. For simplicity, we assume ``\mathbf{E}`` to be in the x direction and to vary sinusoidally in the x direction:

```math
\mathbf{E} \equiv E_0 (\cos kx)\widehat{x}
```

This field distribution has a wavelength ``\lambda = 2\pi / k``, and is the result of a sinusoidal distribution of charges, which we need not specify. In practice, such a charge distribution can arise in a plasma during a wave motion. The equation of motion is

```math
m\frac{d\mathbf{v}}{dt} = q[\mathbf{E}(x) + \mathbf{v}\times\mathbf{B}]
```

whose transverse components are

```math
\begin{aligned}
\dot{v}_x &= \frac{qB}{m}v_y + \frac{q}{m}E_x(x) \\
\dot{v}_y &= -\frac{qB}{m}v_x
\end{aligned}
```

```math
\begin{aligned}
\ddot{v}_x &= -\omega_c^2 v_x \pm \omega_c \frac{\dot{E}_x}{B} \\
\ddot{v}_y &= -\omega_c^2 v_y -\omega_c^2\frac{E_x(x)}{B}
\end{aligned}
```

Here ``E_x(x)`` is the electric field at the position of the particle. To evaluate this, we need to know the particle’s orbit, which we are trying to solve for in the first place. If the electric field is weak, we may, as an approximation, use the *undisturbed orbit* to evaluate ``E_x(x)``. The orbit in the absence of the E field was given before

```math
x = x_0 + r_L\sin \omega_c t
```

so we have

```math
\ddot{v}_y = -\omega_c^2 v_y -\omega_c^2\frac{E_0}{B}\cos k (x_0 + r_L \sin\omega_c t)
```

Anticipating the result, we look for a solution which is the sum of a gyration at ``\omega_c`` and a steady drift ``\mathbf{v}_E``. Since we are interested in finding an expression for ``v_E``, we take out the gyratory motion by averaging over a cycle.
The ``v_x`` component then gives ``\bar{v}_x = 0``.[^1] In the ``v_y`` component, the oscillating term ``\ddot{v}_y`` clearly averages to zero, and we have

[^1]: I am kind of lost here. Probably the logic here is that first we assume the solution has an additional steady drift, so we let ``\ddot{v}_y = 0``? Check Y.Y's note.

```math
\bar{\ddot{v}_y} = 0 = -\omega_c^2 \bar{v}_y -\omega_c^2\frac{E_0}{B}\bar{\cos k (x_0 + r_L \sin\omega_c t)}
```

Expanding the cosine, we have

```math
\cos k (x_0 + r_L \sin\omega_c t) = \cos(kx_0) \cos(kr_L \sin\omega_c t) - \sin(kx_0) \sin(kr_L \sin\omega_c t)
```

It will suffice to treat the small Larmor radius case, ``kr_L \ll 1``. The Taylor expansions allow us to write

```math
\cos k (x_0 + r_L \sin\omega_c t) \approx \cos(kx_0)\big( 1 - \frac{1}{2}k^2r_L^2 \sin^2\omega_c t \big) - \sin(kx_0)k r_L \sin\omega_c t
```

The last term vanishes upon averaging over time, and it gives

```math
\bar{v}_y = -\frac{E_0}{B}\cos(kx_0)\big( 1 - \frac{1}{4}k^2r_L^2 \big) = -\frac{E_x(x_0)}{B}\big( 1 - \frac{1}{4}k^2r_L^2 \big)
```

Thus the usual ``\mathbf{E}\times\mathbf{B}`` drift is modified by the inhomogeneity to read

```math
\mathbf{v}_E = \frac{\mathbf{E}\times\mathbf{B}}{B^2}\big( 1 - \frac{1}{4}k^2r_L^2 \big)
```

The physical reason for this is easy to see. An ion with its guiding center at a maximum of ``\mathbf{E}`` actually spends a good deal of its time in regions of weaker ``\mathbf{E}``. Its average drift, therefore, is less than E/B evaluated at the guiding center. In a linearly varying ``\mathbf{E}`` field, the ion would be in a stronger field on one side of the orbit and in a
field weaker by the same amount on the other side; the correction to ``\mathbf{v}_E`` then cancels out. From this it is clear that the correction term depends on the *second derivative* of ``\mathbf{E}``. For the sinusoidal distribution we assumed, the second derivative is always negative with respect to ``\mathbf{E}``. For an arbitrary variation of ``\mathbf{E}``, we need only replace ``ik`` by ``\nabla`` and write the drift as

```math
\mathbf{v}_E = \Big( 1 + \frac{1}{4}r_L^2\nabla^2 \Big) \frac{\mathbf{E}\times\mathbf{B}}{B^2}
```

The second term is called the *finite-Larmor-radius effect*. What is the significance of this correction? Since ``r_L`` is much larger for ions than for electrons, ``\mathbf{v}_E`` is no longer independent of species. If a density clump occurs in a plasma, an electric field can cause the ions and electrons to separate, generating another electric field. If there is a feedback mechanism that causes the second electric field to enhance the first one, ``\mathbf{E}`` grows indefinitely, and the plasma is unstable. Such an instability, called a *drift instability*, is one type of plasma instabilities. The grad-B drift, of course, is also a finite-Larmor-radius effect and also causes charges to separate. However, ``\mathbf{v}_{\nabla B} \propto kr_L`` whereas the correction term above is proportional to ``k^2 r_L^2``. The nonuniform-E-field effect, therefore, is important at relatively large k, or small scale lengths of the inhomogeneity. For this reason, drift instabilities belong to a more general class called *microinstabilities*.

```@example tutorial
using Tensors: laplace
import Tensors: Vec as Vec3
# using SpecialFunctions

function uniform_B(x)
    return SA[0, 0, 1e-8]
end

function nonuniform_E(x)
    return SA[1e-9*cos(0.3*x[1]), 0, 0]
end

# trace the orbit of the guiding center
function trace_gc!(dx, x, p, t)
    q, m, E, B, sol = p
    xu = sol(t)
    xp = @view xu[1:3]
    Bv = B(xp)
    b = normalize(Bv)
    v_par = (xu[4:6]⋅b).*b  # (v⋅b)b
    v_perp = xu[4:6] - v_par
    r4 = (m*norm(v_perp)/q/norm(Bv))^2/4
    EB(x) = (E(x)×B(x))/norm(B(x))^2
    # dx[1:3] = EB(xp) + v_par
    dx[1:3] = EB(x) + r4*laplace.(EB, Vec3(x...)) + v_par

    # more accurate
    # dx[1:3] = besselj0(0.3*m*norm(v_perp)/q/norm(Bv))*EB(x) + v_par
end

x0 = [1.0, 0, 0]
v0 = [0.0, 1.0, 0.1]
stateinit = [x0..., v0...]
tspan = (0, 20)
param = prepare(nonuniform_E, uniform_B, species=Proton)
prob = ODEProblem(trace!, stateinit, tspan, param)
sol = solve(prob, Tsit5(); save_idxs=[1,2,3,4,5,6])

gc = get_gc(param)
gc_x0 = [gc_i(stateinit) for gc_i in gc]
prob_gc = ODEProblem(trace_gc!, gc_x0, tspan, (param..., sol))
sol_gc = solve(prob_gc, Tsit5(); save_idxs=[1,2,3])

gc_analytic = Tuple(xu -> getindex(sol_gc(xu[7]), i) for i = 1:3)
# numeric result and analytic result
orbit(sol, vars=[(1, 2, 3), gc, gc_analytic])
```

## Time-Varying E Field

Let us now take ``\mathbf{E}`` and ``\mathbf{B}`` to be uniform in space but varying in time. First, consider the case in which ``\mathbf{E}`` alone varies sinusoidally in time, and let it lie along the x axis:

```math
\mathbf{E} = E_0 e^{i\omega t}\widehat{x}
```

Since ``\dot{E}_x = i\omega E_x``, we can write the velocity x-component equation as

```math
\ddot{v}_x = -\omega_c^2 \Big( v_x \mp \frac{i\omega}{\omega_c}\frac{\tilde{E}_x}{B} \Big)
```

Let us define

```math
\begin{aligned}
\tilde{v}_p &\equiv \pm \frac{i\omega}{\omega_c}\frac{\tilde{E}_x}{B} \\
\tilde{v}_E &\equiv \frac{\tilde{E}_x}{B}
\end{aligned}
```

where the tilde has been added merely to emphasize that the drift is oscillating. The plus (minus) sign, as usual, denotes positive (negative) ``q``. Now the x and y velocity component equations can be written as

```math
\begin{aligned}
\ddot{v}_x &= -\omega_c^2(v_x - \tilde{v}_p) \\
\ddot{v}_y &= -\omega_c^2(v_y - \tilde{v}_E)
\end{aligned}
```

By analogy with the derivation in the case of a uniform EM field, we try a solution which is the sum of a drift and a
gyratory motion:

```math
\begin{aligned}
v_x &= v_\perp e^{i\omega_c t} + \tilde{v}_p \\
v_y &= \pm i v_\perp e^{i\omega_c t} + \tilde{v}_E
\end{aligned}
```

If we now differentiate twice with respect to time, we find

```math
\begin{aligned}
\ddot{v}_x &= -\omega_c^2 v_x + (\omega_c^2 - \omega^2)\tilde{v}_p \\
\ddot{v}_y &= -\omega_c^2 v_y + (\omega_c^2 - \omega^2)\tilde{v}_E
\end{aligned}
```

This is **not** the same as the previous expressions right above unless ``\omega^2 \ll \omega_c^2``. If we now make the assumption
that ``\mathbf{E}`` varies slowly, so that ``\omega^2 \ll \omega_c^2``, then there we have the approximate solution.

The solution of velocities in x and y tells us that the guiding center motion has two components. The y component, perpendicular to ``\mathbf{B}`` and ``\mathbf{E}``, is the usual ``\mathbf{E}\times\mathbf{B}`` drift, except that ``v_E`` now oscillates slowly at the frequency ``\omega``. The x component, a new drift *along the direction of* ``\mathbf{E}``, is called the *polarization drift*. By replacing ``i\omega`` with ``\partial/\partial t``, we can generalize the expression of ``v_p`` and define the polarization drift as

```math
\mathbf{v}_p = \pm \frac{1}{\omega_c B}\frac{d\mathbf{E}}{dt}
```

Since ``\mathbf{v}_p`` is in opposite directions for ions and electrons, there is a *polarization current*; for Z = 1, this is

```math
\mathbf{j}_p = ne(v_{ip} - v_{ep}) = \frac{ne}{eB^2}(M+m)\frac{d\mathbf{E}}{dt} = \frac{\rho}{B^2}\frac{d\mathbf{E}}{dt}
```

where ``\rho`` is the mass density.

The physical reason for the polarization current is simple. Consider an ion at rest in a magnetic field. If a field ``\mathbf{E}`` is suddenly applied, the first thing the ion does is to move in the direction of ``\mathbf{E}``. Only after picking up a velocity ``\mathbf{v}`` does the ion feel a Lorentz force ``e\mathbf{v}\times\mathbf{B}`` and begin to move perpendicular to both fields. If ``\mathbf{E}`` is now kept constant, there is no further ``\mathbf{v}_p`` drift but only a ``\mathbf{v}_E`` drift. However, if ``\mathbf{E}`` is reversed, there is again a momentary drift, this time to the left. Thus ``\mathbf{v}_p`` is a startup drift due to inertia and occurs only in the first half-cycle of each gyration during which ``\mathbf{E}`` changes. Consequently, ``\mathbf{v}_p`` goes to zero when ``\omega/\omega_c \ll 1``.

The polarization effect in a plasma is similar to that in a solid dielectric, where ``\mathbf{D} = \epsilon_0\mathbf{E} + \mathbf{P}``. The dipoles in a plasma are ions and electrons separated by a distance ``r_L``. But since ions and electrons can move around to preserve quasineutrality, the application of a steady ``\mathbf{E}`` field does not result in a polarization field ``\mathbf{P}``. However, if ``\mathbf{E}`` oscillates, an oscillating current ``\mathbf{j}_p`` results from the lag due to the ion inertia.

```@example tutorial
function uniform_B(x)
    return SA[0, 0, 1e-8]
end

function time_varying_E(x, t)
    return SA[0, 1e-9*0.1*t, 0]
end

x0 = [1.0, 0, 0]
v0 = [0.0, 1.0, 0.1]
stateinit = [x0..., v0...]
tspan = (0, 100)
param = prepare(time_varying_E, uniform_B, species=Proton)
prob = ODEProblem(trace!, stateinit, tspan, param)
sol = solve(prob, Tsit5(); save_idxs=[1,2,3,4,5,6])
gc = get_gc(param)
v_perp(xu) = hypot(xu[4], xu[5])
gc_y = gc[2]
# polarization drift
monitor(sol, vars=[v_perp, 2, gc_y])
```

## Time-Varying B Field

Finally, we allow the magnetic field to vary in time. Since the Lorentz force is always perpendicular to ``\mathbf{v}``, a magnetic field itself cannot impart energy to a charged particle. However, associated with ``\mathbf{B}`` is an electric field given by

```math
\nabla\times\mathbf{E} = -\dot{\mathbf{B}}
```

and this can accelerate the particles. We can no longer assume the fields to be completely uniform. Let ``\mathbf{v}_\perp = d\mathbf{l}/dt`` be the transverse velocity, ``\mathbf{l}`` being the element of the path along a particle trajectory (with ``v_\parallel`` neglected). Taking the scalar product of the equation of motion with ``\mathbf{v}_\perp``, we have

```math
\frac{d}{dt}\Big( \frac{1}{2}mv_\perp^2 \Big) = q\mathbf{E}\cdot\mathbf{v}_\perp = q\mathbf{E}\cdot\frac{d\mathbf{l}}{dt}
```

The change in one gyration is obtained by integrating over one period:

```math
\delta \Big( \frac{1}{2}mv_\perp^2  \Big) = \int_0^{2\pi/\omega_c}q\mathbf{E}\cdot\frac{d\mathbf{l}}{dt}dt
```

If the field changes slowly, we can replace the time integral by a line integral over the unperturbed orbit:

```math
\delta \Big( \frac{1}{2}mv_\perp^2  \Big) = \oint q\mathbf{E}\cdot d\mathbf{l} = q\int_s (\nabla\times\mathbf{E})\cdot d\mathbf{S} = -q \int_s\dot{\mathbf{B}}\cdot d\mathbf{S}
```

Here ``\mathbf{S}`` is the surface enclosed by the Larmor orbit and has a direction given by the right-hand rule when the fingers point in the direction of ``\mathbf{v}``. Since the plasma is diamagnetic, we have ``\mathbf{B}\cdot d\mathbf{S}<0`` for ions and ``\mathbf{B}\cdot d\mathbf{S}>0`` for electrons. Then

```math
\delta \Big( \frac{1}{2}mv_\perp^2  \Big) = \pm q \dot{B}\pi r_L^2 = \pm q \pi\dot{B}]frac{v_\perp^2}{\omega_c}\frac{m}{\pm qB} = \frac{\frac{1}{2}mv_\perp^2}{B}\cdot \frac{2\pi \dot{B}}{\omega_c}
```

The quantity ``\frac{2\pi\dot{B}}{\omega_c} = \frac{\dot{B}}{\omega_c}`` is just the change ``\delta B`` during one period of gyration. Thus

```math
\delta \Big( \frac{1}{2}mv_\perp^2  \Big) = \mu \delta B
```

Since the left-hand-side is ``\delta(\mu B)``, we have the desired result

```math
\delta \mu = 0
```

*The magnetic moment is invariant in slowly varying magnetic fields.*

As the B field varies in strength, the Larmor orbits expand and contract, and the particles lose and gain transverse energy. This exchange of energy between the particles and the field is described very simply by the invariant of magnetic moment. The invariance of ``\mu`` allows us to prove easily the following well-known theorem:
> The magnetic flux through a Larmor orbit is constant.

The flux ``\Phi`` is given by ``BS``, with ``S = \pi r_L^2``. Thus

```math
\Phi = B\pi\frac{v_\perp^2}{\omega_c^2} = B\pi\frac{v_\perp^2 m^2}{q^2 B^2} = \frac{2\pi m}{q^2}\frac{\frac{1}{2}mv_\perp^2}{B} = \frac{2\pi m}{q^2}\mu
```

Therefore, ``\Phi`` is constant if ``\mu`` is constant.

This property is used in a method of plasma heating known as *adiabatic compression*. A plasma is injected into a sequence of magnetic mirrors and by keep increasing the magnetic field in subsequent mirrors we can increase the plasma velocities.

## Summary of Guiding Center Drifts

General force:

```math
\mathbf{v}_f = \frac{1}{q}\frac{\mathbf{F}\times\mathbf{B}}{B^2}
```

Electric field:

```math
\mathbf{v}_E = \frac{\mathbf{E}\times\mathbf{B}}{B^2}
```

Gravitational field:

```math
\mathbf{v}_g = \frac{m}{q}\frac{\mathbf{g}\times\mathbf{B}}{B^2}
```

Nonuniform electric field:

```math
\mathbf{v}_E = \Big( 1+\frac{1}{4}r_L^2 \nabla^2 \Big)\frac{\mathbf{E}\times\mathbf{B}}{B^2}
```

Nonuniform magnetic field:

Grad-B:

```math
\mathbf{v}_{\nabla B} = \pm \frac{1}{2}v_\perp r_L\frac{\mathbf{B}\times\nabla B}{B^2}
```

Curvature drift:

```math
\mathbf{v}_R = \frac{mv_\parallel^2}{q}\frac{\mathbf{R}_c \times\mathbf{B}}{R_c^2 B^2}
```

Curved vacuum field:

```math
\mathbf{v}_R + \mathbf{v}_{\nabla B} = \frac{m}{q}\Big( v_\parallel^2 + \frac{1}{2}v_\perp^2 \Big) \frac{\mathbf{R}_c \times\mathbf{B}}{R_c^2 B^2}
```

Polarization drift:[^2]

```math
\mathbf{v}_p = \pm \frac{1}{\omega_c B}\frac{d\mathbf{E}}{dt}
```

[^2]: In common test particle models, we assume static EM fields, so the polarization drift as well as adiabatic heating is not present. However, it is easily achieveable here in this package.

## Adiabatic Invariants

It is well known in classical mechanics that whenever a system has a periodic motion, the action integral ``\oint p dq`` taken over a period is a constant of the motion. Here ``p`` and ``q`` are the generalized momentum and coordinate which repeat themselves in the motion. If a slow change is made in the system, so that the motion is not quite periodic, the constant of the motion does not change and is then called an *adiabatic invariant*. By slow here we mean slow compared with the period of motion, so that the integral ``\oint p dq`` is well defined even though it is strictly no longer an integral over a closed path. Adiabatic invariants play an important role in plasma physics; they allow us to obtain simple answers in many instances involving
complicated motions. There are three adiabatic invariants, each corresponding to a different type of periodic motion.

### The First Adiabatic Invariant

We have already met the quantity

```math
\mu = mv_\perp^2 / 2B
```

and have proved its invariance in spatially and temporally varying ``\mathbf{B}`` fields. The periodic motion involved, of course, is the Larmor gyration. If we take ``p`` to be angular momentum ``mv_\perp r`` and ``dq`` to be the coordinate ``d\theta``, the action integral becomes

```math
\oint p dq = \oint mv_\perp r d\theta = 2\pi r_L m v_\perp = 2\pi \frac{mv_\perp^2}{\omega_c} = 4\pi \frac{m}{|q|}\mu
```

Thus μ is a constant of the motion as long as ``q/m`` is not changed. We have proved the invariance of μ only with the implicit assumption ``\omega/\omega_c \ll 1``, where ``\omega`` is a frequency characterizing the rate of change of ``\mathbf{B}`` as seen by the particle. A proof exists, however, that μ is invariant even when ``\omega/\omega_c \le q``. In theorists’ language, μ is
invariant “to all orders in an expansion in ω/ω c .” What this means in practice is that μ remains much more nearly constant than ``\mathbf{B}`` does during one period of gyration.

It is just as important to know when an adiabatic invariant does *not* exist as to know when it does. Adiabatic invariance of μ is violated when ω is not small compared with ``\omega_c`` . We give three examples of this.

* *Magnetic Pumping*. If the strength of ``\mathbf{B}`` in a mirror confinement system is varied sinusoidally, the particles’ ``v_\perp`` would oscillate; but there would be no gain of energy in the long run. However, if the particles make collisions, the
invariance of μ is violated, and the plasma can be heated. In particular, a particle making a collision during the compression phase can transfer part of its gyration energy into ``v_\parallel`` energy, and this is not taken out again in the expansion
phase.

* *Cyclotron Heating*. Now imagine that the ``\mathbf{B}`` field is oscillated at the frequency ``\omega_c``. The induced electric field will then rotate in phase with some of the particles and accelerate their Larmor motion continuously. The condition ``\omega\ll \omega_c`` is violated, μ is not conserved, and the plasma can be heated.

* *Magnetic Cusps*. If the current in one of the coils in a simple magnetic mirror system is reversed, a magnetic cusp is formed. This configuration has, in addition to the usual mirrors, a spindle-cusp mirror extending over ``360^o`` in azimuth. A plasma confined in a cusp device is supposed to have better stability properties than that in an ordinary mirror. Unfortunately, the loss-cone losses are larger because of the additional loss region; and the particle motion is nonadiabatic. Since the ``\mathbf{B}`` field vanishes at the center of symmetry, ``\omega_c`` is zero there; and μ is not preserved. The local Larmor radius near the center is larger than the device. Because of this, the adiabatic invariant μ does not guarantee that particles outside a loss cone will stay outside after passing through the nonadiabatic region. Fortunately, there is in this case another invariant: the
canonical angular momentum ``p_\theta = mrv_\theta - erA_\theta``. This ensures that there will be a population of particles trapped indefinitely until they make a collision.

### The Second Adiabatic Invariant

Consider a particle trapped between two magnetic mirrors: it bounces between them and therefore has a periodic motion at the “bounce frequency”. A constant of this motion is given by ``\oint mv_\parallel ds``, where ``ds`` is an element of path length (of the guiding center) along a field line. However, since the guiding center drifts across field lines, the motion is not exactly periodic, and the constant of the motion becomes an adiabatic invariant. This is called the *longitudinal invariant* ``J`` and is
defined for a half-cycle between the two turning points

```math
J = \int_a^b v_\parallel ds
```

We shall prove that ``J`` is invariant in a static, nonuniform B field; the result is also true for a slowly time-varying B field.

Before embarking on this somewhat lengthy proof, let us consider an example of the type of problem in which a theorem on the invariance of ``J`` would be useful. As we have already seen, the earth’s magnetic field mirror-traps charged particles, which slowly drift in longitude around the earth. If the magnetic field were perfectly symmetric, the particle would eventually drift back to the same magnetic field line. However, the actual field is distorted by such effects as the solar wind. In that case, will a particle ever come back to the same magnetic field line? Since the particle’s energy is conserved and is equal to ``\frac{1}{2} mv_\perp^2`` at the turning point, the invariance of μ indicates that ``|B|`` remains the same at the turning point. However, upon drifting back to the same longitude, a particle may find itself on another magnetic field line at a different altitude. This cannot happen if ``J`` is conserved. ``J`` determines the length of the field lines between turning points, and no two lines
have the same length between points with the same ``|B|``. Consequently, the particle returns to the same magnetic field line even in a slightly asymmetric field.

To prove the invariance of ``J``, we first consider the invariance of ``v_\parallel \delta s``, where ``\delta s`` is a segment of the path along ``\mathbf{B}``. Because of guiding center drifts, a particle on ``s`` will find itself on another magnetic field line ``\delta s^\prime`` after a time ``\Delta t``. The length of ``\delta s^\prime`` is defined by passing planes perpendicular to ``\mathbf{B}`` through the end points of ``\delta s``. The length of ``\delta s`` is obviously proportional to the radius of curvature:

```math
\frac{\delta s}{R_c} = \frac{\delta s^\prime}{R_c^\prime}
```

so that

```math
\frac{\delta s^\prime - \delta s}{\Delta t \delta s} = \frac{R_c^\prime - R_c}{\Delta t R_c}
```

The "radial" component of ``\mathbf{v}_{gc}`` is just

```math
\mathbf{v}_{gc}\cdot \frac{\mathbf{R}_c}{R_c} = \frac{R_c^\prime - R_c}{\Delta t}
```

The guiding center drift in curved vacuum field is

```math
\mathbf{v}_{gc} = \mathbf{v}_R + \mathbf{v}_{\nabla B} = \pm \frac{1}{2}v_\perp r_L\frac{\mathbf{B}\times\nabla B}{B^2} + \frac{mv_\parallel^2}{q}\frac{\mathbf{R}_c \times\mathbf{B}}{R_c^2 B^2}
```

The curvature drift has no component along ``\mathbf{R}_c``. Using the above three equations, we have

```math
\frac{1}{\delta s}\frac{d}{dt}\delta s = \mathbf{v}_{gs} \cdot \frac{\mathbf{R}_c}{R_c^2} = \frac{1}{2}\frac{m}{q}\frac{v_\perp^2}{B^3}(\mathbf{B}\times\nabla B)\cdot\frac{\mathbf{R}_c}{R_c^2}
```

This is the rate of change of ``\delta s`` as seen by the particle. We must now get the rate of change of ``v_\parallel`` as seen by the particle. The parallel and perpendicular energies are defined by

```math
W \equiv \frac{1}{2}mv_\parallel^2 + \frac{1}{2}mv_\parallel^2 = \frac{1}{2}mv_\parallel^2 + \mu B \equiv W_\parallel + W_\perp
```

Thus ``v_\parallel`` can be written

```math
v_\parallel = \big[ \frac{2}{m}(W - \mu B) \big]^{1/2}
```

Here W and μ are constant, and only B varies. Therefore,

```math
\frac{\dot{v}_\parallel}{v_\parallel} = -\frac{1}{2}\frac{\mu\dot{B}}{W - \mu B} = -\frac{1}{2}\frac{\mu \dot{B}}{W_\parallel} = -\frac{\mu\dot{B}}{mv_\parallel^2}
```

Since B was assumed static, ``\dot{B}`` is not zero only because of the guiding center motion:

```math
\dot{B} = \frac{dB}{d\mathbf{r}}\cdot\frac{d\mathbf{r}}{dt} = \mathbf{v}_{gc}\cdot\nabla B = \frac{mv_\parallel^2}{q}\frac{\mathbf{R}_c \times\mathbf{B}}{R_c^2 B^2} \cdot\nabla B 
```

Now we have

```math
\frac{\dot{v}_\parallel}{v_\parallel} = -\frac{\mu}{q}\frac{(\mathbf{R}_c\times\mathbf{B})\cdot\nabla B}{R_c^2 B^2} = -\frac{1}{2}\frac{m}{q}\frac{v_\perp^2}{B} \frac{(\mathbf{R}_c\times\mathbf{B})\cdot\nabla B}{R_c^2 B^2}
```

The fractional change in ``v_\parallel \delta s`` is

```math
\frac{1}{v_\parallel \delta s}\frac{d}{dt}(v_\parallel \delta s) = \frac{1}{\delta s}\frac{d\delta s}{dt} + \frac{1}{v_\parallel}\frac{dv_\parallel}{dt}
```

From the previous derivations we see that the these two terms cancel, so that

```math
v_\parallel \delta s = \textrm{constant}
```

This is not exactly the same as saying that ``J`` is constant, however. In taking the integral of ``v_\parallel \delta s``, between the turning points, it may be that the turning points on ``\delta s^\prime`` do not coincide with the intersections of the perpendicular planes. However, any error in ``J`` arising from such a discrepancy is negligible because near the turning points, ``v_\parallel`` is nearly zero. Consequently, we have proved

```math
J = \int_a^b v_\parallel ds = \textrm{constant}
```

An example of the violation of J invariance is given by a plasma heating scheme called *transit-time magnetic pumping*. Suppose an oscillating current is applied to the coils of a mirror system so that the mirrors alternately approach and withdraw from each other near the bounce frequency. Those particles that have the right bounce frequency will always see an approaching mirror and will therefore gain ``v_\parallel``. ``J`` is not conserved in this case because the change of ``\mathbf{B}`` occurs on a time scale not long compared with the bounce time.

### The Third Adiabatic Invariant

Referring again to the earth dipole case, we see that the slow drift of a guiding center around the earth constitutes a third type of periodic motion. The adiabatic invariant connected with this turns out to be the total magnetic flux ``\Phi`` enclosed by the drift surface. It is almost obvious that, as ``\mathbf{B}`` varies, the particle will stay on a surface such that the total
number of magnetic field lines enclosed remains constant. This invariant, ``\Phi``, has few applications because most fluctuations of ``\mathbf{B}`` occur on a time scale short compared with the drift period. As an example of the violation of ``\Phi`` invariance, we can cite some recent work on the excitation of hydromagnetic waves in the ionosphere. These waves have a long period comparable to the drift time of a particle around the earth. The particles can therefore encounter the wave in the same phase each time around. If the phase is right, the wave can be excited by the conversion of particle drift energy to wave energy.
